==> qttools-opensource-src_5.2.1.orig.tar.xz: qttools-opensource-src-5.2.1/src/windeployqt/qmlutils.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the tools applications of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QMLUTILS_H
#define QMLUTILS_H

#include <QStringList>

QT_BEGIN_NAMESPACE

QString findQmlDirectory(int platform, const QString &startDirectoryName);

struct QmlImportScanResult {
    struct Module {
        QString relativeInstallPath() const;
        QString installPath(const QString &root) const;

        QString name;
        QString className;
        QString sourcePath;
    };

    QmlImportScanResult() : ok(false) {}
    void append(const QmlImportScanResult &other);

    bool ok;
    QList<Module> modules;
    QStringList plugins;
};

QmlImportScanResult runQmlImportScanner(const QString &directory, const QString &qmlImportPath,
                                        int platform, bool debug, QString *errorMessage);

QT_END_NAMESPACE

#endif // QMLUTILS_H

==> qttools-opensource-src_5.4.1.orig.tar.xz: qttools-opensource-src-5.4.1/src/windeployqt/qmlutils.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the tools applications of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL21$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia. For licensing terms and
** conditions see http://qt.digia.com/licensing. For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file. Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights. These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QMLUTILS_H
#define QMLUTILS_H

#include "utils.h"

#include <QStringList>

QT_BEGIN_NAMESPACE

QString findQmlDirectory(int platform, const QString &startDirectoryName);

struct QmlImportScanResult {
    struct Module {
        QString relativeInstallPath() const;
        QString installPath(const QString &root) const;

        QString name;
        QString className;
        QString sourcePath;
    };

    QmlImportScanResult() : ok(false) {}
    void append(const QmlImportScanResult &other);

    bool ok;
    QList<Module> modules;
    QStringList plugins;
};

QmlImportScanResult runQmlImportScanner(const QString &directory, const QString &qmlImportPath,
                                        int platform, DebugMatchMode debugMatchMode,
                                        QString *errorMessage);

QT_END_NAMESPACE

#endif // QMLUTILS_H
